Corrected project name in header comments
[pulseview.git] / main.cpp
index 3d6b86e3651b3004c95d87c8d7d0c77c41024613..d15cff89ee61ed852be33065e764be35e5253366 100644 (file)
--- a/main.cpp
+++ b/main.cpp
@@ -1,5 +1,5 @@
 /*
* This file is part of the sigrok project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>
  *
@@ -34,7 +34,7 @@ int main(int argc, char *argv[])
 
        /* Set some application metadata. */
        QApplication::setApplicationVersion(APP_VERSION);
-       QApplication::setApplicationName("sigrok-qt");
+       QApplication::setApplicationName("PulseView");
        QApplication::setOrganizationDomain("http://www.sigrok.org");
 
        /* Initialise libsigrok */
@@ -1,5 +1,5 @@
 /*
- * This file is part of the sigrok project.
+ * This file is part of the PulseView project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>